#!/bin/bash
#
# tftpd		Start and stop the standalone tftpd-hpa server.
#
# chkconfig:	2345 96 34
# description:	H. Peter Anvin's version of BSD TFTP daemon with \
#		RFC 2347 option negotiation, blksize (RFC 2348), \
#		tsize (RFC 2349), and timeout (RFC 2349) options.
# processname: tftpd
# pidfile: /var/run/tftpd.pid
# config: /etc/sysconfig/tftpd
#


# Source function library.
. /etc/init.d/functions

# Source networking configuration and check that networking is up.
if [ -r /etc/sysconfig/network ] ; then
	. /etc/sysconfig/network
	[ ${NETWORKING} = "no" ] && exit 0
fi

if [ -f /etc/sysconfig/tftpd ]; then
   . /etc/sysconfig/tftpd
fi


tftpd=/usr/sbin/tftpd

RETVAL=0

function start() {
        # Start daemons.
	prog=`basename ${tftpd}`
        echo -n $"Starting $prog: "
	daemon ${tftpd} -v -l -a $TFTPDADDRESS -u $TFTPDUSER -s $TFTPDCHROOT
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && touch /var/lock/subsys/tftpd
	return $RETVAL
}

function stop() {
        # Stop daemons.
	prog=`basename ${tftpd}`
	echo -n $"Stopping $prog: "
	killproc ${tftpd}
	RETVAL=$?
	echo
        [ $RETVAL -eq 0 ] && rm -f /var/lock/subsys/tftpd
	return $RETVAL
}

# See how we were called.
case "$1" in
    start)
        start
        ;;
    stop)
        stop
        ;;
    status)
        status ${tftpd}
	;;
    restart)
	stop
	start
	;;
    reload)
    	killproc ${tftpd} -HUP
	RETVAL=$?
	;;
    condrestart)
        if [ -f /var/lock/subsys/tftpd ] ; then
            stop
            start
        fi
	;;
    *)
	echo $"Usage: $0 {start|stop|restart|status|condrestart}"
	RETVAL=1
esac

exit $RETVAL
